@@ -485,8 +485,8 @@ def auto_rescale(img, dim):
 
     scale = (dim, dim)
 
-    if img.shape[2] == 1:
-        img_array = np.expand_dims(img, 3)
+    if len(img.shape) == 2:
+        img_array = np.expand_dims(img, 2)
     else:
         img_array = img
 
